@@ -5,7 +5,7 @@
 
 .noGenerics <- TRUE
 
-.onUnload <- function(libpath)
-    library.dynam.unload("asypow", libpath)
+.Last.lib <- function(libpath) {
+    library.dynam.unload("asypow", libpath) }
 
 
